@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: being.h 4321 2008-06-02 11:42:26Z b_lindeijer $
+ *  $Id: being.h 4545 2008-08-28 20:29:06Z b_lindeijer $
  */
 
 #ifndef _TMW_BEING_H
@@ -47,6 +47,7 @@ class Map;
 class Graphics;
 class ImageSet;
 class Particle;
+class Text;
 
 /**
  * A position along a being's path.
@@ -93,8 +94,12 @@ class Being : public Sprite
             SHOE_SPRITE,
             BOTTOMCLOTHES_SPRITE,
             TOPCLOTHES_SPRITE,
+            MISC1_SPRITE,
+            MISC2_SPRITE,
             HAIR_SPRITE,
             HAT_SPRITE,
+            CAPE_SPRITE,
+            GLOVES_SPRITE,
             WEAPON_SPRITE,
             SHIELD_SPRITE,
             VECTOREND_SPRITE
@@ -183,7 +188,7 @@ class Being : public Sprite
          *
          * @param name The name that should appear.
          */
-        void
+        virtual void
         setName(const std::string &name) { mName = name; }
 
         /**
@@ -234,24 +239,12 @@ class Being : public Sprite
         virtual void
         logic();
 
-        /**
-         * Draws the speech text above the being.
-         */
-        void
-        drawSpeech(Graphics *graphics, int offsetX, int offsetY);
-
         /**
          * Draws the emotion picture above the being.
          */
         void
         drawEmotion(Graphics *graphics, int offsetX, int offsetY);
 
-        /**
-         * Draws the name text below the being.
-         */
-        virtual void
-        drawName(Graphics *, int, int) {};
-
         /**
          * Returns the type of the being.
          */
@@ -359,7 +352,21 @@ class Being : public Sprite
          */
         void controlParticle(Particle *particle);
 
-        void setEmote(Uint8 emotion, Uint8 emote_time) { mEmotion = emotion; mEmotionTime = emote_time; }
+        void setEmote(Uint8 emotion, Uint8 emote_time)
+        {
+            mEmotion = emotion;
+            mEmotionTime = emote_time;
+        }
+
+        /**
+         * Triggers a visual effect, such as `level up'
+         *
+         * Only draws the visual effect, does not play sound effects
+         *
+         * \param effectId ID of the effect to trigger
+         */
+        virtual void
+        triggerEffect(int effectId) { internalTriggerEffect(effectId, false, true); }
 
         const std::auto_ptr<Equipment> mEquipment;
 
@@ -369,11 +376,26 @@ class Being : public Sprite
          */
         void setPath(const Path &path);
 
+        /**
+         * Let the sub-classes react to a replacement
+         */
+        virtual void updateCoords() {}
+
         /**
          * Returns the sprite direction of this being.
          */
         SpriteDirection getSpriteDirection() const;
 
+        /**
+         * Trigger visual effect, with components
+         *
+         * \param effectId ID of the effect to trigger
+         * \param sfx Whether to trigger sound effects
+         * \param gfx Whether to trigger graphical effects
+         */
+        void
+        internalTriggerEffect(int effectId, bool sfx, bool gfx);
+
         Uint32 mId;                     /**< Unique sprite id */
         Uint16 mWalkSpeed;              /**< Walking speed */
         Uint8 mDirection;               /**< Facing direction */
@@ -385,7 +407,7 @@ class Being : public Sprite
         const ItemInfo* mEquippedWeapon;
 
         Path mPath;
-        std::string mSpeech;
+        Text *mSpeech;
         Uint16 mHairStyle, mHairColor;
         Uint8 mGender;
         Uint32 mSpeechTime;
