@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: beingmanager.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: beingmanager.h 4237 2008-05-14 18:57:32Z b_lindeijer $
  */
 
 #ifndef _TMW_BEINGMANAGER_H
@@ -67,6 +67,7 @@ class BeingManager
          * Return a being at specific coordinates.
          */
         Being* findBeing(Uint16 x, Uint16 y, Being::Type type = Being::UNKNOWN);
+        Being* findBeingByPixel(Uint16 x, Uint16 y);
 
         /**
          * Return a being nearest to specific coordinates.
@@ -77,6 +78,11 @@ class BeingManager
         Being* findNearestLivingBeing(Uint16 x, Uint16 y, int maxdist,
                                       Being::Type type = Being::UNKNOWN);
 
+        /**
+         * Finds a being by name and (optionally) by type.
+         */
+        Being* findBeingByName(std::string name, Being::Type type = Being::UNKNOWN);
+
         /**
          * Return a being nearest to another being.
          *
