@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: equipment.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: equipment.h 4347 2008-06-12 09:06:01Z b_lindeijer $
  */
 
 #ifndef _TMW_EQUIPMENT_H_
@@ -39,8 +39,8 @@ class Equipment
         /**
          * Get equipment at the given slot.
          */
-        Item*
-        getEquipment(int index) { return mEquipment[index]; }
+        Item* getEquipment(int index) const
+        { return mEquipment[index]; }
 
         /**
          * Set equipment at the given slot.
@@ -71,7 +71,7 @@ class Equipment
         void
         setArrows(Item *arrows) { mArrows = arrows; }
 
-    protected:
+    private:
         Item *mEquipment[EQUIPMENT_SIZE];
         Item *mArrows;
 };
