@@ -18,30 +18,25 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: floor_item.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: floor_item.cpp 4347 2008-06-12 09:06:01Z b_lindeijer $
  */
 
 #include "floor_item.h"
 
 #include "map.h"
 
-#include "resources/itemdb.h"
-#include "resources/iteminfo.h"
-
-
 FloorItem::FloorItem(unsigned int id,
                      unsigned int itemId,
                      unsigned short x,
                      unsigned short y,
                      Map *map):
     mId(id),
-    mItemId(itemId),
     mX(x),
     mY(y),
     mMap(map)
 {
-    // Retrieve item image from item info
-    mImage = ItemDB::get(itemId).getImage();
+    // Create a corresponding item instance
+    mItem = new Item(itemId);
 
     // Add ourselves to the map
     mSpriteIterator = mMap->addSprite(this);
@@ -51,4 +46,6 @@ FloorItem::~FloorItem()
 {
     // Remove ourselves from the map
     mMap->removeSprite(mSpriteIterator);
+
+    delete mItem;
 }
