@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: browserbox.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: browserbox.cpp 4348 2008-06-14 12:42:49Z the_enemy $
  */
 
 #include <algorithm>
@@ -50,7 +50,7 @@ BrowserBox::BrowserBox(unsigned int mode):
     addMouseListener(this);
 
 #ifdef USE_OPENGL
-    if (config.getValue("opengl", 0)) {
+    if (config.getValue("opengl", 0.0f)) {
         if (instances == 0) {
             browserFont = new gcn::ImageFont(
                     "graphics/gui/browserfont.png",
@@ -314,7 +314,8 @@ BrowserBox::draw(gcn::Graphics *graphics)
 
         for (j = 0; j < row.size(); j++)
         {
-            if (mUseLinksAndUserColors || (!mUseLinksAndUserColors && (j == 0)))
+            if ( (mUseLinksAndUserColors && (j + 3) <= row.size()) ||
+                    (!mUseLinksAndUserColors && (j == 0)) )
             {
                 // Check for color change in format "##x", x = [L,P,0..9]
                 if ((row.at(j) == '#') && (row.at(j + 1) == '#'))
@@ -380,8 +381,7 @@ BrowserBox::draw(gcn::Graphics *graphics)
             }
 
             // Check for line separators in format "---"
-            if ((j <= 3) && (row.at(j) == '-') && (row.at(j + 1) == '-') &&
-                    (row.at(j + 2) == '-'))
+            if (row == "---")
             {
                 for (x = 0; x < getWidth(); x++)
                 {
