@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: button.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: button.cpp 4045 2008-04-07 15:23:07Z b_lindeijer $
  */
 
 #include <algorithm>
@@ -82,7 +82,7 @@ Button::Button(const std::string& caption, const std::string &actionEventId,
 
 void Button::init()
 {
-    setBorderSize(0);
+    setFrameSize(0);
 
     if (mInstances == 0)
     {
