@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: char_server.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: char_server.cpp 4425 2008-07-17 22:52:53Z b_lindeijer $
  */
 
 #include "char_server.h"
@@ -48,8 +48,10 @@ class ServerListModel : public gcn::ListModel {
         std::string getElementAt(int i);
 };
 
-ServerSelectDialog::ServerSelectDialog(LoginData *loginData):
-    Window("Select Server"), mLoginData(loginData)
+ServerSelectDialog::ServerSelectDialog(LoginData *loginData, int nextState):
+    Window("Select Server"),
+    mLoginData(loginData),
+    mNextState(nextState)
 {
     mServerListModel = new ServerListModel();
     mServerList = new ListBox(mServerListModel);
@@ -69,7 +71,7 @@ ServerSelectDialog::ServerSelectDialog(LoginData *loginData):
     mScrollArea->setDimension(gcn::Rectangle(
                 5, 5, 200 - 2 * 5,
                 100 - 3 * 5 - mCancelButton->getHeight() -
-                mScrollArea->getBorderSize()));
+                mScrollArea->getFrameSize()));
 
     mServerList->setActionEventId("ok");
 
@@ -105,10 +107,12 @@ ServerSelectDialog::action(const gcn::ActionEvent &event)
         const SERVER_INFO *si = server_info[mServerList->getSelected()];
         mLoginData->hostname = iptostring(si->address);
         mLoginData->port = si->port;
-        state = CHAR_CONNECT_STATE;
+        mLoginData->updateHost = si->updateHost;
+
+        state = mNextState;
     }
     else if (event.getId() == "cancel") {
-        state = LOADDATA_STATE;
+        state = LOGIN_STATE;
     }
 }
 
