@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: char_server.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: char_server.h 4425 2008-07-17 22:52:53Z b_lindeijer $
  */
 
 #ifndef _CHAR_SEL_SERVER_H
@@ -46,7 +46,7 @@ class ServerSelectDialog : public Window, public gcn::ActionListener {
          *
          * @see Window::Window
          */
-        ServerSelectDialog(LoginData *loginData);
+        ServerSelectDialog(LoginData *loginData, int nextState);
 
         /**
          * Destructor.
@@ -63,6 +63,7 @@ class ServerSelectDialog : public Window, public gcn::ActionListener {
         ServerListModel *mServerListModel;
         gcn::ListBox *mServerList;
         gcn::Button *mOkButton;
+        int mNextState;
 };
 
 #endif
