@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: chat.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: chat.h 4402 2008-07-08 15:16:22Z the_enemy $
  */
 
 #ifndef _TMW_CHAT_H
@@ -44,7 +44,7 @@ class ScrollArea;
 #define BY_SERVER     3
 
 #define ACT_WHISPER   4   // getting whispered at
-#define ACT_IS        5   // equivalent to "/me" in irc
+#define ACT_IS        5   // equivalent to "/me" on IRC
 
 #define BY_LOGGER     6
 
@@ -58,6 +58,8 @@ class ScrollArea;
 #define IS_WHO_LENGTH       4
 #define IS_CLEAR            "/clear"
 #define IS_CLEAR_LENGTH     6
+#define IS_WHISPER          "/whisper"
+#define IS_WHISPER_LENGTH   8
 
 /**
  * gets in between usernick and message text depending on
@@ -65,7 +67,7 @@ class ScrollArea;
  */
 #define CAT_NORMAL        ": "
 #define CAT_IS            ""
-#define CAT_WHISPER       " says: "
+#define CAT_WHISPER       " whispers: "
 
 /** job dependend identifiers (?)  */
 #define SKILL_BASIC       0x0001
@@ -97,7 +99,9 @@ class ScrollArea;
 #define RFAIL_GENERIC     0x0a
 
 /** should always be zero if failed */
-#define SKILL_FAILED    0x00
+#define SKILL_FAILED      0x00
+
+#define DEFAULT_CHAT_WINDOW_SCROLL 7 // 1 means `1/8th of the window size'.
 
 struct CHATSKILL
 {
@@ -153,9 +157,9 @@ class ChatWindow : public Window, public gcn::ActionListener,
         /**
          * Checks whether ChatWindow is Focused or not.
          */
-        bool isFocused();
+        bool isInputFocused();
 
-        /*
+        /**
          * Determines whether to send a command or an ordinary message, then
          * contructs packets & sends them.
          *
@@ -194,6 +198,25 @@ class ChatWindow : public Window, public gcn::ActionListener,
         void
         setVisible(bool visible);
 
+       /**
+        * Scrolls the chat window
+        *
+        * @param amount direction and amount to scroll.  Negative numbers scroll
+        * up, positive numbers scroll down.  The absolute amount indicates the
+        * amount of 1/8ths of chat window real estate that should be scrolled.
+        */
+        void
+        scroll(int amount);
+
+        /**
+         * help implements the /help command
+         *
+         * @param msg1 is the command that the player needs help on
+         * @param msg2 is the sub-command relating to the command
+         */
+        void
+        help(const std::string &msg1, const std::string &msg2);
+
     private:
         Network *mNetwork;
         bool mTmpVisible;
@@ -222,4 +245,3 @@ class ChatWindow : public Window, public gcn::ActionListener,
 extern ChatWindow *chatWindow;
 
 #endif
-
