@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: checkbox.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: checkbox.h 4045 2008-04-07 15:23:07Z b_lindeijer $
  */
 
 #ifndef _TMW_CHECKBOX_H
@@ -40,7 +40,7 @@ class CheckBox : public gcn::CheckBox {
         /**
          * Constructor.
          */
-        CheckBox(const std::string& caption, bool marked = false);
+        CheckBox(const std::string& caption, bool selected = false);
 
         /**
          * Destructor.
