@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: equipmentwindow.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: equipmentwindow.cpp 4347 2008-06-12 09:06:01Z b_lindeijer $
  */
 
 #include "equipmentwindow.h"
@@ -61,22 +61,20 @@ void EquipmentWindow::draw(gcn::Graphics *graphics)
         graphics->drawRectangle(gcn::Rectangle(10 + 36 * (i % 4),
                 36 * (i / 4) + 25, 32, 32));
 
-        if (!(item = mEquipment->getEquipment(i))) {
+        if (!(item = mEquipment->getEquipment(i)))
             continue;
-        }
 
-        image = item->getInfo().getImage();
+        image = item->getImage();
         static_cast<Graphics*>(graphics)->drawImage(
                 image, 36 * (i % 4) + 10, 36 * (i / 4) + 25);
     }
 
     graphics->drawRectangle(gcn::Rectangle(160, 25, 32, 32));
 
-    if (!(item = mEquipment->getArrows())) {
+    if (!(item = mEquipment->getArrows()))
         return;
-    }
 
-    image = item->getInfo().getImage();
+    image = item->getImage();
 
     static_cast<Graphics*>(graphics)->drawImage(image, 160, 25);
     graphics->drawText(toString(item->getQuantity()), 170, 62,
