@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: gccontainer.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: gccontainer.cpp 4208 2008-04-29 11:25:26Z b_lindeijer $
  */
 
 #include "gccontainer.h"
@@ -37,21 +37,15 @@ GCContainer::~GCContainer()
     mDeathList.clear();
 }
 
-void GCContainer::add(gcn::Widget *w, bool delChild)
+void GCContainer::add(gcn::Widget *w)
 {
-    if (delChild) {
-        mDeathList.push_back(w);
-    }
-
+    mDeathList.push_back(w);
     Container::add(w);
 }
 
-void GCContainer::add(gcn::Widget *w, int x, int y, bool delChild)
+void GCContainer::add(gcn::Widget *w, int x, int y)
 {
-    if (delChild) {
-        mDeathList.push_back(w);
-    }
-
+    mDeathList.push_back(w);
     Container::add(w, x, y);
 }
 
