@@ -18,17 +18,16 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: inventorywindow.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: inventorywindow.h 4347 2008-06-12 09:06:01Z b_lindeijer $
  */
 
 #ifndef _TMW_INVENTORYWINDOW_H
 #define _TMW_INVENTORYWINDOW_H
 
 #include <guichan/actionlistener.hpp>
+#include <guichan/selectionlistener.hpp>
 
-#include "selectionlistener.h"
 #include "window.h"
-#include "windowlistener.h"
 
 #include "../guichanfwd.h"
 
@@ -40,8 +39,8 @@ class ItemContainer;
  *
  * \ingroup Interface
  */
-class InventoryWindow : public Window, gcn::ActionListener, SelectionListener,
-    WindowListener
+class InventoryWindow : public Window, gcn::ActionListener,
+    gcn::SelectionListener
 {
     public:
         /**
@@ -59,21 +58,22 @@ class InventoryWindow : public Window, gcn::ActionListener, SelectionListener,
          */
         void action(const gcn::ActionEvent &event);
 
-        void mouseClicked(gcn::MouseEvent &event);
-
-        Item* getItem();
+        /**
+         * Returns the selected item.
+         */
+        Item* getSelectedItem() const;
 
         /**
          * Updates labels to currently selected item.
-         *
-         * @see SelectionListener::selectionChanged.
          */
-        void selectionChanged(const SelectionEvent &event);
+        void valueChanged(const gcn::SelectionEvent &event);
+
+        void mouseClicked(gcn::MouseEvent &event);
 
         /**
-         * Called whenever the window is resized.
+         * Called whenever the widget changes size.
          */
-        void windowResized(const WindowEvent &event);
+        void widgetResized(const gcn::Event &event);
 
     private:
         void updateButtons();    /**< Updates button states. */
