@@ -18,19 +18,18 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: itemcontainer.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: itemcontainer.cpp 4347 2008-06-12 09:06:01Z b_lindeijer $
  */
 
 #include "itemcontainer.h"
 
 #include <guichan/mouseinput.hpp>
-
-#include "selectionlistener.h"
+#include <guichan/selectionlistener.hpp>
 
 #include "../graphics.h"
 #include "../inventory.h"
 #include "../item.h"
-//#include "../itemshortcut.h"
+#include "../itemshortcut.h"
 #include "../log.h"
 
 #include "../resources/image.h"
@@ -39,6 +38,9 @@
 
 #include "../utils/tostring.h"
 
+const int ItemContainer::gridWidth = 36;  // item icon width + 4
+const int ItemContainer::gridHeight = 42; // item icon height + 10
+
 ItemContainer::ItemContainer(Inventory *inventory):
     mInventory(inventory),
     mSelectedItem(NULL)
@@ -51,6 +53,7 @@ ItemContainer::ItemContainer(Inventory *inventory):
     mMaxItems = mInventory->getLastUsedSlot() - 1; // Count from 0, usage from 2
 
     addMouseListener(this);
+    addWidgetListener(this);
 }
 
 ItemContainer::~ItemContainer()
@@ -68,15 +71,13 @@ ItemContainer::logic()
     if (i != mMaxItems)
     {
         mMaxItems = i;
-        setWidth(getWidth());
+        recalculateHeight();
     }
 }
 
 void
 ItemContainer::draw(gcn::Graphics *graphics)
 {
-    int gridWidth = 36; //(item icon width + 4)
-    int gridHeight = 42; //(item icon height + 10)
     int columns = getWidth() / gridWidth;
 
     // Have at least 1 column
@@ -100,9 +101,8 @@ ItemContainer::draw(gcn::Graphics *graphics)
     {
         Item *item = mInventory->getItem(i);
 
-        if (item->getQuantity() <= 0) {
+        if (!item || item->getQuantity() <= 0)
             continue;
-        }
 
         int itemX = ((i - 2) % columns) * gridWidth;
         int itemY = ((i - 2) / columns) * gridHeight;
@@ -115,8 +115,8 @@ ItemContainer::draw(gcn::Graphics *graphics)
         }
 
         // Draw item icon
-        Image* image;
-        if ((image = item->getInfo().getImage()) != NULL)
+        Image* image = item->getImage();
+        if (image)
         {
             static_cast<Graphics*>(graphics)->drawImage(
                     image, itemX, itemY);
@@ -131,26 +131,26 @@ ItemContainer::draw(gcn::Graphics *graphics)
     }
 }
 
-void
-ItemContainer::setWidth(int width)
+void ItemContainer::widgetResized(const gcn::Event &event)
 {
-    gcn::Widget::setWidth(width);
+    recalculateHeight();
+}
 
-    int gridWidth = 36; //item icon width + 4
-    int gridHeight = 46; //item icon height + 14
-    int columns = getWidth() / gridWidth;
+void ItemContainer::recalculateHeight()
+{
+    int cols = getWidth() / gridWidth;
 
-    if (columns < 1)
-    {
-        columns = 1;
-    }
+    if (cols < 1)
+        cols = 1;
 
-    setHeight(((mMaxItems / columns) +
-            (mMaxItems % columns > 0 ? 1 : 0)) * gridHeight);
+    const int rows = (mMaxItems / cols) + (mMaxItems % cols > 0 ? 1 : 0);
+    const int height = rows * gridHeight + 8;
+    if (height != getHeight())
+        setHeight(height);
 }
 
 Item*
-ItemContainer::getItem()
+ItemContainer::getSelectedItem() const
 {
     return mSelectedItem;
 }
@@ -167,20 +167,20 @@ ItemContainer::setSelectedItem(Item *item)
     if (mSelectedItem != item)
     {
         mSelectedItem = item;
-        fireSelectionChangedEvent();
+        distributeValueChangedEvent();
     }
 }
 
 void
-ItemContainer::fireSelectionChangedEvent()
+ItemContainer::distributeValueChangedEvent()
 {
-    SelectionEvent event(this);
-    SelectionListeners::iterator i_end = mListeners.end();
-    SelectionListeners::iterator i;
+    gcn::SelectionEvent event(this);
+    std::list<gcn::SelectionListener*>::iterator i_end = mListeners.end();
+    std::list<gcn::SelectionListener*>::iterator i;
 
     for (i = mListeners.begin(); i != i_end; ++i)
     {
-        (*i)->selectionChanged(event);
+        (*i)->valueChanged(event);
     }
 }
 
@@ -191,14 +191,12 @@ ItemContainer::mousePressed(gcn::MouseEvent &event)
 
     if (button == gcn::MouseEvent::LEFT || button == gcn::MouseEvent::RIGHT)
     {
-        int gridWidth = 36; //(item icon width + 4)
-        int gridHeight = 42; //(item icon height + 10)
         int columns = getWidth() / gridWidth;
         int mx = event.getX();
         int my = event.getY();
         int index = mx / gridWidth + ((my / gridHeight) * columns) + 2;
 
-        //itemShortcut->setItemSelected(NULL);
+        itemShortcut->setItemSelected(-1);
         // Fix for old server, it should be: if (index >= mMaxItems)
         if (index > mMaxItems + 1)
         {
@@ -207,9 +205,9 @@ ItemContainer::mousePressed(gcn::MouseEvent &event)
         }
         Item *item = mInventory->getItem(index);
         setSelectedItem(item);
-        //if (!item->isEquipment())
-        //{
-        //    itemShortcut->setItemSelected(item);
-        //}
+        if (item && !item->isEquipment())
+        {
+            itemShortcut->setItemSelected(item->getId());
+        }
     }
 }
