@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: menuwindow.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: menuwindow.cpp 4060 2008-04-09 14:49:07Z b_lindeijer $
  */
 
 #include "menuwindow.h"
@@ -35,7 +35,7 @@ extern Window *inventoryWindow;
 extern Window *equipmentWindow;
 extern Window *skillDialog;
 extern Window *statusWindow;
-//extern Window *itemShortcutWindow;
+extern Window *itemShortcutWindow;
 
 namespace {
     struct MenuWindowListener : public gcn::ActionListener
@@ -62,7 +62,7 @@ MenuWindow::MenuWindow():
         "Equipment",
         "Inventory",
         "Skills",
-//        "Shortcut",
+        "Shortcut",
         "Setup",
         0
     };
@@ -107,10 +107,10 @@ void MenuWindowListener::action(const gcn::ActionEvent &event)
     {
         window = skillDialog;
     }
-    //else if (event.getId() == "Shortcut")
-    //{
-    //    window = itemShortcutWindow;
-    //}
+    else if (event.getId() == "Shortcut")
+    {
+        window = itemShortcutWindow;
+    }
     else if (event.getId() == "Setup")
     {
         window = setupWindow;
