@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: playerbox.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: playerbox.cpp 4045 2008-04-07 15:23:07Z b_lindeijer $
  */
 
 #include <algorithm>
@@ -39,7 +39,7 @@ ImageRect PlayerBox::background;
 PlayerBox::PlayerBox(const Player *player):
     mPlayer(player)
 {
-    setBorderSize(2);
+    setFrameSize(2);
 
     if (instances == 0)
     {
@@ -83,7 +83,7 @@ PlayerBox::draw(gcn::Graphics *graphics)
     {
         // Draw character
         int x, y, bs;
-        bs = getBorderSize();
+        bs = getFrameSize();
         x = getWidth() / 2 - 16 + bs;
         y = getHeight() / 2 + bs;
         mPlayer->draw(static_cast<Graphics*>(graphics), x, y);
@@ -91,10 +91,10 @@ PlayerBox::draw(gcn::Graphics *graphics)
 }
 
 void
-PlayerBox::drawBorder(gcn::Graphics *graphics)
+PlayerBox::drawFrame(gcn::Graphics *graphics)
 {
     int w, h, bs;
-    bs = getBorderSize();
+    bs = getFrameSize();
     w = getWidth() + bs * 2;
     h = getHeight() + bs * 2;
 
