@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: popupmenu.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: popupmenu.cpp 4243 2008-05-16 15:48:52Z the_enemy $
  */
 
 #include "popupmenu.h"
@@ -38,6 +38,7 @@
 #include "../item.h"
 #include "../localplayer.h"
 #include "../npc.h"
+#include "../player_relations.h"
 
 #include "../resources/iteminfo.h"
 #include "../resources/itemdb.h"
@@ -75,8 +76,29 @@ void PopupMenu::showPopup(int x, int y, Being *being)
                 // add as buddy will be options in this menu.
                 const std::string &name = mBeing->getName();
                 mBrowserBox->addRow("@@trade|Trade With " + name + "@@");
-
                 mBrowserBox->addRow("@@attack|Attack " + name + "@@");
+
+                mBrowserBox->addRow("##3---");
+
+                switch (player_relations.getRelation(name)) {
+                case PlayerRelation::NEUTRAL:
+                    mBrowserBox->addRow("@@friend|Befriend " + name + "@@");
+
+                case PlayerRelation::FRIEND:
+                    mBrowserBox->addRow("@@disregard|Disregard " + name + "@@");
+                    mBrowserBox->addRow("@@ignore|Ignore " + name + "@@");
+                    break;
+
+                case PlayerRelation::DISREGARDED:
+                    mBrowserBox->addRow("@@unignore|Un-Ignore " + name + "@@");
+                    mBrowserBox->addRow("@@ignore|Completely ignore " + name + "@@");
+                    break;
+
+                case PlayerRelation::IGNORED:
+                    mBrowserBox->addRow("@@unignore|Un-Ignore " + name + "@@");
+                    break;
+                }
+
                 //mBrowserBox->addRow("@@follow|Follow " + name + "@@");
                 //mBrowserBox->addRow("@@buddy|Add " + name + " to Buddy List@@");
             }
@@ -144,6 +166,34 @@ void PopupMenu::handleLink(const std::string& link)
         player_node->attack(mBeing, true);
     }
 
+    else if (link == "unignore" &&
+             mBeing != NULL &&
+             mBeing->getType() == Being::PLAYER)
+    {
+        player_relations.setRelation(mBeing->getName(), PlayerRelation::NEUTRAL);
+    }
+
+    else if (link == "ignore" &&
+             mBeing != NULL &&
+             mBeing->getType() == Being::PLAYER)
+    {
+        player_relations.setRelation(mBeing->getName(), PlayerRelation::IGNORED);
+    }
+
+    else if (link == "disregard" &&
+             mBeing != NULL &&
+             mBeing->getType() == Being::PLAYER)
+    {
+        player_relations.setRelation(mBeing->getName(), PlayerRelation::DISREGARDED);
+    }
+
+    else if (link == "friend" &&
+             mBeing != NULL &&
+             mBeing->getType() == Being::PLAYER)
+    {
+        player_relations.setRelation(mBeing->getName(), PlayerRelation::FRIEND);
+    }
+
     /*
     // Follow Player action
     else if (link == "follow")
@@ -243,9 +293,9 @@ void PopupMenu::showPopup(int x, int y)
 {
     setContentSize(mBrowserBox->getWidth() + 8, mBrowserBox->getHeight() + 8);
     if (windowContainer->getWidth() < (x + getWidth() + 5))
-        x -= (getWidth() + 50);
+        x = windowContainer->getWidth() - getWidth();
     if (windowContainer->getHeight() < (y + getHeight() + 5))
-        y -= (getHeight() + 50);
+        y = windowContainer->getHeight() - getHeight();
     setPosition(x, y);
     setVisible(true);
     requestMoveToTop();
