@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: radiobutton.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: radiobutton.cpp 4045 2008-04-07 15:23:07Z b_lindeijer $
  */
 
 #include "radiobutton.h"
@@ -67,7 +67,7 @@ void RadioButton::drawBox(gcn::Graphics* graphics)
 {
     Image *box = NULL;
 
-    if (mMarked) {
+    if (isSelected()) {
         if (isEnabled()) {
             box = radioChecked;
         } else {
