@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: register.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: register.cpp 4045 2008-04-07 15:23:07Z b_lindeijer $
  */
 
 #include "register.h"
@@ -235,7 +235,7 @@ RegisterDialog::action(const gcn::ActionEvent &event)
             mLoginData->port = (short) config.getValue("port", 0);
             mLoginData->username = mUserField->getText();
             mLoginData->password = mPasswordField->getText();
-            mLoginData->username += mFemaleButton->isMarked() ? "_F" : "_M";
+            mLoginData->username += mFemaleButton->isSelected() ? "_F" : "_M";
             mLoginData->registerLogin = true;
 
             state = ACCOUNT_STATE;
