@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: scrollarea.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: scrollarea.cpp 4204 2008-04-28 18:29:04Z b_lindeijer $
  */
 
 #include <algorithm>
@@ -153,26 +153,18 @@ void ScrollArea::logic()
         if (getHorizontalScrollPolicy() == gcn::ScrollArea::SHOW_NEVER)
         {
             content->setWidth(getChildrenArea().width -
-                    2 * content->getBorderSize());
+                    2 * content->getFrameSize());
         }
         if (getVerticalScrollPolicy() == gcn::ScrollArea::SHOW_NEVER)
         {
             content->setHeight(getChildrenArea().height -
-                    2 * content->getBorderSize());
+                    2 * content->getFrameSize());
         }
     }
 }
 
 void ScrollArea::draw(gcn::Graphics *graphics)
 {
-    checkPolicies();
-
-    int alpha = getBaseColor().a;
-    gcn::Color highlightColor = getBaseColor() + 0x303030;
-    highlightColor.a = alpha;
-    gcn::Color shadowColor = getBaseColor() - 0x303030;
-    shadowColor.a = alpha;
-
     if (mVBarVisible)
     {
         drawUpButton(graphics);
@@ -198,34 +190,12 @@ void ScrollArea::draw(gcn::Graphics *graphics)
                     mScrollbarWidth));
     }
 
-    gcn::Widget *content = getContent();
-
-    if (content != NULL)
-    {
-        graphics->pushClipArea(getChildrenArea());
-
-        if (content->getBorderSize() > 0)
-        {
-            gcn::Rectangle rec = content->getDimension();
-            rec.x -= content->getBorderSize();
-            rec.y -= content->getBorderSize();
-            rec.width += 2 * content->getBorderSize();
-            rec.height += 2 * content->getBorderSize();
-            graphics->pushClipArea(rec);
-            content->drawBorder(graphics);
-            graphics->popClipArea();
-        }
-
-        graphics->pushClipArea(content->getDimension());
-        content->draw(graphics);
-        graphics->popClipArea();
-        graphics->popClipArea();
-    }
+    drawChildren(graphics);
 }
 
-void ScrollArea::drawBorder(gcn::Graphics *graphics)
+void ScrollArea::drawFrame(gcn::Graphics *graphics)
 {
-    int bs = getBorderSize();
+    int bs = getFrameSize();
     int w = getWidth() + bs * 2;
     int h = getHeight() + bs * 2;
 
@@ -240,10 +210,10 @@ void ScrollArea::setOpaque(bool opaque)
     mOpaque = opaque;
 
     if (mOpaque) {
-        setBorderSize(2);
+        setFrameSize(2);
     }
     else {
-        setBorderSize(0);
+        setFrameSize(0);
     }
 }
 
