@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: scrollarea.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: scrollarea.h 4204 2008-04-28 18:29:04Z b_lindeijer $
  */
 
 #ifndef __TMW_SCROLLAREA_H__
@@ -34,17 +34,18 @@ class ImageRect;
  *
  * \ingroup GUI
  */
-class ScrollArea : public gcn::ScrollArea {
+class ScrollArea : public gcn::ScrollArea
+{
     public:
         /**
          * Constructor.
          */
-        ScrollArea(bool gc=true);
+        ScrollArea(bool gc = true);
 
         /**
          * Constructor.
          */
-        ScrollArea(gcn::Widget *content, bool gc=true);
+        ScrollArea(gcn::Widget *content, bool gc = true);
 
         /**
          * Destructor.
@@ -65,19 +66,17 @@ class ScrollArea : public gcn::ScrollArea {
         /**
          * Draws the background and border of the scroll area.
          */
-        void drawBorder(gcn::Graphics *graphics);
+        void drawFrame(gcn::Graphics *graphics);
 
         /**
          * Sets whether the widget should draw its background or not.
          */
-        void
-        setOpaque(bool opaque);
+        void setOpaque(bool opaque);
 
         /**
          * Returns whether the widget draws its background or not.
          */
-        bool
-        isOpaque() { return mOpaque; }
+        bool isOpaque() const { return mOpaque; }
 
     protected:
         enum BUTTON_DIR {
