@@ -18,17 +18,16 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: sell.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: sell.h 4347 2008-06-12 09:06:01Z b_lindeijer $
  */
 
 #ifndef _TMW_SELL_H
 #define _TMW_SELL_H
 
 #include <guichan/actionlistener.hpp>
+#include <guichan/selectionlistener.hpp>
 
 #include "window.h"
-#include "selectionlistener.h"
-#include "windowlistener.h"
 
 #include "../guichanfwd.h"
 
@@ -42,8 +41,7 @@ class ShopListBox;
  *
  * \ingroup Interface
  */
-class SellDialog : public Window, gcn::ActionListener, SelectionListener,
-    WindowListener
+class SellDialog : public Window, gcn::ActionListener, gcn::SelectionListener
 {
     public:
         /**
@@ -66,7 +64,7 @@ class SellDialog : public Window, gcn::ActionListener, SelectionListener,
         /**
          * Adds an item to the inventory.
          */
-        void addItem(Item *item, int price);
+        void addItem(const Item *item, int price);
 
         /**
          * Called when receiving actions from the widgets.
@@ -78,12 +76,12 @@ class SellDialog : public Window, gcn::ActionListener, SelectionListener,
          *
          * @see SelectionListener::selectionChanged
          */
-        void selectionChanged(const SelectionEvent &event);
+        void valueChanged(const gcn::SelectionEvent &event);
 
         /**
-         * Called whenever the window is resized.
+         * Called whenever the widget changes size.
          */
-        void windowResized(const WindowEvent &event);
+        void widgetResized(const gcn::Event &event);
 
         /**
          * Gives Player's Money amount
