@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: setup.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: setup.h 4237 2008-05-14 18:57:32Z b_lindeijer $
  */
 
 #ifndef _TMW_SETUP_H
@@ -48,7 +48,7 @@ class Setup : public Window, public gcn::ActionListener
         /**
          * Destructor.
          */
-        ~Setup();
+        virtual ~Setup();
 
         /**
          * Event handling method.
