@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: setup_audio.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: setup_audio.cpp 4045 2008-04-07 15:23:07Z b_lindeijer $
  */
 
 #include "setup_audio.h"
@@ -70,7 +70,7 @@ Setup_Audio::Setup_Audio():
 
 void Setup_Audio::apply()
 {
-    if (mSoundCheckBox->isMarked())
+    if (mSoundCheckBox->isSelected())
     {
         config.setValue("sound", 1);
         try {
@@ -95,7 +95,7 @@ void Setup_Audio::apply()
 
 void Setup_Audio::cancel()
 {
-    mSoundCheckBox->setMarked(mSoundEnabled);
+    mSoundCheckBox->setSelected(mSoundEnabled);
 
     sound.setSfxVolume(mSfxVolume);
     mSfxSlider->setValue(mSfxVolume);
