@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: setup_joystick.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: setup_joystick.cpp 4045 2008-04-07 15:23:07Z b_lindeijer $
  */
 
 #include "setup_joystick.h"
@@ -43,7 +43,7 @@ Setup_Joystick::Setup_Joystick():
     mCalibrateButton->setPosition(10, 30 + mCalibrateLabel->getHeight());
 
     mOriginalJoystickEnabled = (int)config.getValue("joystickEnabled", 0) != 0;
-    mJoystickEnabled->setMarked(mOriginalJoystickEnabled);
+    mJoystickEnabled->setSelected(mOriginalJoystickEnabled);
 
     mJoystickEnabled->addActionListener(this);
 
@@ -60,7 +60,7 @@ void Setup_Joystick::action(const gcn::ActionEvent &event)
 
     if (event.getSource() == mJoystickEnabled)
     {
-        joystick->setEnabled(mJoystickEnabled->isMarked());
+        joystick->setEnabled(mJoystickEnabled->isSelected());
     }
     else
     {
@@ -83,7 +83,7 @@ void Setup_Joystick::cancel()
     {
         joystick->setEnabled(mOriginalJoystickEnabled);
     }
-    mJoystickEnabled->setMarked(mOriginalJoystickEnabled);
+    mJoystickEnabled->setSelected(mOriginalJoystickEnabled);
 }
 
 void Setup_Joystick::apply()
