@@ -23,8 +23,6 @@
 
 #include "shoplistbox.h"
 
-#include "selectionlistener.h"
-
 #include <guichan/font.hpp>
 #include <guichan/graphics.hpp>
 #include <guichan/listmodel.hpp>
@@ -79,7 +77,7 @@ void ShopListBox::draw(gcn::Graphics *gcnGraphics)
             backgroundColor = gcn::Color(110, 160, 255);
         }
         else if (mShopItems &&
-                mPlayerMoney < mShopItems->at(i).price && mPriceCheck)
+                mPlayerMoney < mShopItems->at(i)->getPrice() && mPriceCheck)
         {
             backgroundColor = gcn::Color(0x919191);
         }
@@ -89,7 +87,7 @@ void ShopListBox::draw(gcn::Graphics *gcnGraphics)
 
         if (mShopItems)
         {
-            Image *icon = mShopItems->at(i).image;
+            Image *icon = mShopItems->at(i)->getImage();
             if (icon)
             {
                 graphics->drawImage(icon, 1, y);
@@ -101,37 +99,12 @@ void ShopListBox::draw(gcn::Graphics *gcnGraphics)
     }
 }
 
-void ShopListBox::setSelected(int selected)
-{
-    if (!mListModel)
-    {
-        mSelected = -1;
-    }
-    else
-    {
-        // Update mSelected with bounds checking
-        mSelected = std::min(mListModel->getNumberOfElements() - 1,
-                             std::max(-1, selected));
-
-        gcn::Widget *parent = getParent();
-        if (parent && mSelected >= 0)
-        {
-            gcn::Rectangle scroll;
-            scroll.y = mRowHeight * mSelected;
-            scroll.height = mRowHeight;
-            parent->showWidgetPart(this, scroll);
-        }
-    }
-
-    fireSelectionChangedEvent();
-}
-
 void ShopListBox::mousePressed(gcn::MouseEvent &event)
 {
     if (event.getButton() == gcn::MouseEvent::LEFT)
     {
         setSelected(event.getY() / mRowHeight);
-        generateAction();
+        distributeActionEvent();
     }
 }
 
