@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: tabbedcontainer.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: tabbedcontainer.cpp 4045 2008-04-07 15:23:07Z b_lindeijer $
  */
 
 #include <algorithm>
@@ -82,8 +82,8 @@ void TabbedContainer::logic()
 {
     if (mActiveContent) {
         mActiveContent->setSize(
-                getWidth() - 2 * mActiveContent->getBorderSize(),
-                getHeight() - TABHEIGHT - 2 * mActiveContent->getBorderSize());
+                getWidth() - 2 * mActiveContent->getFrameSize(),
+                getHeight() - TABHEIGHT - 2 * mActiveContent->getFrameSize());
     }
 
     Container::logic();
