@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: textbox.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: textbox.h 4096 2008-04-16 08:39:59Z b_lindeijer $
  */
 
 #ifndef __TMW_TEXTBOX_H__
@@ -40,15 +40,10 @@ class TextBox : public gcn::TextBox {
          */
         TextBox();
 
-        /**
-         * Constructor.
-         */
-        TextBox(const std::string& text);
-
         /**
          * Sets the text after wrapping it to the current width of the widget.
          */
-        void setText(const std::string &text);
+        void setTextWrapped(const std::string &text);
 };
 
 #endif
