@@ -73,7 +73,7 @@ TradeWindow::TradeWindow(Network *network):
     mPartnerScroll = new ScrollArea(mPartnerItemContainer);
     mPartnerScroll->setPosition(8, 64);
 
-    mMoneyLabel = new gcn::Label("You get: 0z");
+    mMoneyLabel = new gcn::Label("You get: 0 GP");
     mMoneyLabel2 = new gcn::Label("You give:");
     mMoneyField = new TextField();
 
@@ -136,7 +136,7 @@ TradeWindow::~TradeWindow()
 
 void TradeWindow::addMoney(int amount)
 {
-    mMoneyLabel->setCaption("You get: " + toString(amount) + "z");
+    mMoneyLabel->setCaption("You get: " + toString(amount) + " GP");
     mMoneyLabel->adjustSize();
 }
 
@@ -184,7 +184,7 @@ void TradeWindow::reset()
     mOkButton->setEnabled(true);
     mOkOther = false;
     mOkMe = false;
-    mMoneyLabel->setCaption("You get: 0z");
+    mMoneyLabel->setCaption("You get: 0 GP");
     mMoneyField->setEnabled(true);
     mMoneyField->setText("");
 }
@@ -225,19 +225,19 @@ void TradeWindow::tradeItem(Item *item, int quantity)
     outMsg.writeInt32(quantity);
 }
 
-void TradeWindow::selectionChanged(const SelectionEvent &event)
+void TradeWindow::valueChanged(const gcn::SelectionEvent &event)
 {
-    Item *item;
+    const Item *item;
 
     /* If an item is selected in one container, make sure no item is selected
      * in the other container.
      */
     if (event.getSource() == mMyItemContainer &&
-            (item = mMyItemContainer->getItem()))
+            (item = mMyItemContainer->getSelectedItem()))
     {
         mPartnerItemContainer->selectNone();
     }
-    else if ((item = mPartnerItemContainer->getItem()))
+    else if ((item = mPartnerItemContainer->getSelectedItem()))
     {
         mMyItemContainer->selectNone();
     }
@@ -262,19 +262,15 @@ void TradeWindow::selectionChanged(const SelectionEvent &event)
 
 void TradeWindow::action(const gcn::ActionEvent &event)
 {
-    Item *item = inventoryWindow->getItem();
+    Item *item = inventoryWindow->getSelectedItem();
 
     if (event.getId() == "add")
     {
         if (!item)
-        {
             return;
-        }
 
         if (mMyInventory->getFreeSlot() < 1)
-        {
             return;
-        }
 
         if (mMyInventory->contains(item)) {
             chatWindow->chatLog("Failed adding item. You can not "
