@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: updatewindow.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: updatewindow.h 4332 2008-06-05 07:33:12Z b_lindeijer $
  */
 
 #ifndef _UPDATERWINDOW_H
@@ -49,9 +49,14 @@ class UpdaterWindow : public Window, public gcn::ActionListener
 {
  public:
     /**
-     * Constructor
+     * Constructor.
+     *
+     * @param updateHost Host where to get the updated files.
+     * @param updatesDir Directory where to store updates (should be absolute
+     *                   and already created).
      */
-    UpdaterWindow();
+    UpdaterWindow(const std::string &updateHost,
+                  const std::string &updatesDir);
 
     /**
      * Destructor
@@ -124,15 +129,15 @@ class UpdaterWindow : public Window, public gcn::ActionListener
     /** Host where we get the updated files. */
     std::string mUpdateHost;
 
+    /** Place where the updates are stored (absolute path). */
+    std::string mUpdatesDir;
+
     /** The file currently downloading. */
     std::string mCurrentFile;
 
     /** The Adler32 checksum of the file currently downloading. */
     unsigned long mCurrentChecksum;
 
-    /** Absolute path to locally save downloaded files. */
-    std::string mBasePath;
-
     /** A flag to indicate whether to use a memory buffer or a regular file. */
     bool mStoreInMemory;
 
