@@ -18,11 +18,12 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: window.cpp 4442 2008-07-23 17:23:30Z umperio $
+ *  $Id: window.cpp 4463 2008-08-06 19:43:58Z b_lindeijer $
  */
 
 #include <algorithm>
 #include <climits>
+#include <cassert>
 
 #include <guichan/exception.hpp>
 #include <guichan/widgets/icon.hpp>
@@ -135,14 +136,15 @@ Window::~Window()
     const std::string &name = mWindowName;
 
     // Saving X, Y and Width and Height for resizables in the config
-    config.setValue(name + "WinX", getX());
-    config.setValue(name + "WinY", getY());
-    config.setValue(name + "Visible", isVisible());
+    if (!name.empty()) {
+        config.setValue(name + "WinX", getX());
+        config.setValue(name + "WinY", getY());
+        config.setValue(name + "Visible", isVisible());
 
-    if (mGrip)
-    {
-        config.setValue(name + "WinWidth", getWidth());
-        config.setValue(name + "WinHeight", getHeight());
+        if (mGrip) {
+            config.setValue(name + "WinWidth", getWidth());
+            config.setValue(name + "WinHeight", getHeight());
+        }
     }
 
     instances--;
@@ -474,6 +476,7 @@ void
 Window::loadWindowState()
 {
     const std::string &name = mWindowName;
+    assert(!name.empty());
 
     setPosition((int) config.getValue(name + "WinX", mDefaultX),
                 (int) config.getValue(name + "WinY", mDefaultY));
