@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: imageparticle.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: imageparticle.cpp 4360 2008-06-23 14:44:20Z crush_tmw $
  */
 
 #include "imageparticle.h"
@@ -56,7 +56,7 @@ void ImageParticle::draw(Graphics *graphics, int offsetX, int offsetY) const
         return;
     }
 
-    float alphafactor = 1.0f;
+    float alphafactor = mAlpha;
 
     if (mLifetimeLeft > -1 && mLifetimeLeft < mFadeOut)
         alphafactor *= (float) mLifetimeLeft / (float) mFadeOut;
