@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: item.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: item.h 4347 2008-06-12 09:06:01Z b_lindeijer $
  */
 
 #ifndef _ITEM_H_
@@ -26,6 +26,8 @@
 
 #include "resources/itemdb.h"
 
+class Image;
+
 /**
  * Represents one or more instances of a certain item type.
  */
@@ -36,24 +38,18 @@ class Item
          * Constructor.
          */
         Item(int id = -1, int quantity = 0,
-             bool equipment = false, bool equipped = false):
-            mId(id),
-            mQuantity(quantity),
-            mEquipment(equipment),
-            mEquipped(equipped)
-        {
-        }
+             bool equipment = false, bool equipped = false);
 
         /**
          * Destructor.
          */
-        ~Item() {}
+        ~Item();
 
         /**
          * Sets the item id, identifying the item type.
          */
         void
-        setId(int id) { mId = id; }
+        setId(int id);
 
         /**
          * Returns the item id.
@@ -61,6 +57,11 @@ class Item
         int
         getId() const { return mId; }
 
+        /**
+         * Returns the item image.
+         */
+        Image* getImage() { return mImage; }
+
         /**
          * Sets the number of items.
          */
@@ -123,6 +124,7 @@ class Item
 
     protected:
         int mId;              /**< Item type id. */
+        Image *mImage;        /**< Item image. */
         int mQuantity;        /**< Number of items. */
         bool mEquipment;      /**< Item is equipment. */
         bool mEquipped;       /**< Item is equipped. */
