@@ -61,11 +61,15 @@ class Logger
         /**
          * Enters a message in the log. The message will be timestamped.
          */
-        void log(const char *log_text, ...);
+        void log(const char *log_text, ...)
+#ifdef __GNUC__
+            __attribute__((__format__(__printf__, 2, 3)))
+#endif
+            ;
 
         /**
-         * Log an error and quit. The error will pop-up in Windows and will be
-         * printed to standard error everywhere else.
+         * Log an error and quit. The error will pop-up on Windows and Mac, and
+         * will be printed to standard error everywhere else.
          */
         void error(const std::string &error_text);
 
