@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: main.cpp 4426 2008-07-17 23:08:17Z b_lindeijer $
+ *  $Id: main.cpp 4460 2008-08-04 07:17:06Z peaveydk $
  */
 
 #include "main.h"
@@ -159,7 +159,7 @@ void setUpdatesDir()
     // If updatesHost is currently empty, fill it from config file
     if (updateHost.empty()) {
         updateHost =
-            config.getValue("updatehost", "http://updates.thanaworld.org");
+            config.getValue("updatehost", "http://updates.themanaworld.org");
     }
 
     // Remove any trailing slash at the end of the update host
