@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: beinghandler.h 2112 2006-01-22 13:31:13Z der_doener $
+ *  $Id: beinghandler.h 4540 2008-08-28 18:01:15Z b_lindeijer $
  */
 
 #ifndef _TMW_NET_BEINGHANDLER_H
@@ -29,9 +29,13 @@
 class BeingHandler : public MessageHandler
 {
     public:
-        BeingHandler();
+        BeingHandler(bool);
 
         void handleMessage(MessageIn *msg);
+
+    private:
+        // Should we honor server "Stop Walking" packets
+        bool mSync;
 };
 
 #endif
