@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: buysellhandler.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: buysellhandler.cpp 4347 2008-06-12 09:06:01Z b_lindeijer $
  */
 
 #include "buysellhandler.h"
@@ -29,6 +29,7 @@
 #include "protocol.h"
 
 #include "../beingmanager.h"
+#include "../inventory.h"
 #include "../item.h"
 #include "../localplayer.h"
 #include "../npc.h"
@@ -99,7 +100,7 @@ void BuySellHandler::handleMessage(MessageIn *msg)
                     Sint32 value = msg->readInt32();
                     msg->readInt32();  // OCvalue
 
-                    Item *item = player_node->getInvItem(index);
+                    Item *item = player_node->getInventory()->getItem(index);
                     if (item && !(item->isEquipped())) {
                         sellDialog->addItem(item, value);
                     }
