@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: chathandler.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: chathandler.cpp 4237 2008-05-14 18:57:32Z b_lindeijer $
  */
 
 #include "chathandler.h"
@@ -32,6 +32,7 @@
 #include "../being.h"
 #include "../beingmanager.h"
 #include "../game.h"
+#include "../player_relations.h"
 
 #include "../gui/chat.h"
 
@@ -40,11 +41,15 @@
 
 extern Being *player_node;
 
+#define SERVER_NAME "Server"
+
 ChatHandler::ChatHandler()
 {
     static const Uint16 _messages[] = {
         SMSG_BEING_CHAT,
         SMSG_PLAYER_CHAT,
+        SMSG_WHISPER,
+        SMSG_WHISPER_RESPONSE,
         SMSG_GM_CHAT,
         SMSG_WHO_ANSWER,
         0x10c, // MVP
@@ -57,12 +62,50 @@ void ChatHandler::handleMessage(MessageIn *msg)
 {
     Being *being;
     std::string chatMsg;
+    std::string nick;
     Sint16 chatMsgLength;
 
     switch (msg->getId())
     {
+        case SMSG_WHISPER_RESPONSE:
+            switch (msg->readInt8())
+            {
+                case 0x00:
+                    // comment out since we'll local echo in chat.cpp instead, then only report failures
+                    //chatWindow->chatLog("Whisper sent", BY_SERVER);
+                    break;
+                case 0x01:
+                    chatWindow->chatLog("Whisper could not be sent, user is offline", BY_SERVER);
+                    break;
+                case 0x02:
+                    chatWindow->chatLog("Whisper could not be sent, ignored by user", BY_SERVER);
+                    break;
+            }
+            break;
+
+        // Received whisper
+        case SMSG_WHISPER:
+            chatMsgLength = msg->readInt16() - 28;
+            nick = msg->readString(24);
+
+            if (chatMsgLength <= 0)
+                break;
+
+            chatMsg = msg->readString(chatMsgLength);
+            if (nick != SERVER_NAME)
+                chatMsg = nick + " : " + chatMsg;
+
+            if (nick == SERVER_NAME)
+                chatWindow->chatLog(chatMsg, BY_SERVER);
+            else {
+                if (player_relations.hasPermission(nick, PlayerRelation::WHISPER))
+                    chatWindow->chatLog(chatMsg, ACT_WHISPER);
+            }
+
+            break;
+
         // Received speech from being
-        case SMSG_BEING_CHAT:
+        case SMSG_BEING_CHAT: {
             chatMsgLength = msg->readInt16() - 8;
             being = beingManager->findBeing(msg->readInt32());
 
@@ -72,14 +115,27 @@ void ChatHandler::handleMessage(MessageIn *msg)
             }
 
             chatMsg = msg->readString(chatMsgLength);
-            chatWindow->chatLog(chatMsg, BY_OTHER);
-            chatMsg.erase(0, chatMsg.find(" : ", 0) + 3);
+
+            std::string::size_type pos = chatMsg.find(" : ", 0);
+            std::string sender_name = ((pos == std::string::npos)
+                                       ? ""
+                                       : chatMsg.substr(0, pos));
+
+            // We use getIgnorePlayer instead of ignoringPlayer here because ignorePlayer' side
+            // effects are triggered right below for Being::IGNORE_SPEECH_FLOAT.
+            if (player_relations.checkPermissionSilently(sender_name, PlayerRelation::SPEECH_LOG))
+                chatWindow->chatLog(chatMsg, BY_OTHER);
+
+            chatMsg.erase(0, pos + 3);
             trim(chatMsg);
-            being->setSpeech(chatMsg, SPEECH_TIME);
+
+            if (player_relations.hasPermission(sender_name, PlayerRelation::SPEECH_FLOAT))
+                being->setSpeech(chatMsg, SPEECH_TIME);
             break;
+        }
 
         case SMSG_PLAYER_CHAT:
-        case SMSG_GM_CHAT:
+        case SMSG_GM_CHAT: {
             chatMsgLength = msg->readInt16() - 4;
 
             if (chatMsgLength <= 0)
@@ -88,17 +144,17 @@ void ChatHandler::handleMessage(MessageIn *msg)
             }
 
             chatMsg = msg->readString(chatMsgLength);
+            std::string::size_type pos = chatMsg.find(" : ", 0);
 
             if (msg->getId() == SMSG_PLAYER_CHAT)
             {
                 chatWindow->chatLog(chatMsg, BY_PLAYER);
 
-                std::string::size_type pos = chatMsg.find(" : ", 0);
                 if (pos != std::string::npos)
-                {
                     chatMsg.erase(0, pos + 3);
-                }
+
                 trim(chatMsg);
+
                 player_node->setSpeech(chatMsg, SPEECH_TIME);
             }
             else
@@ -106,6 +162,7 @@ void ChatHandler::handleMessage(MessageIn *msg)
                 chatWindow->chatLog(chatMsg, BY_GM);
             }
             break;
+        }
 
         case SMSG_WHO_ANSWER:
             chatWindow->chatLog("Online users: " + toString(msg->readInt32()),
