@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: equipmenthandler.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: equipmenthandler.cpp 4347 2008-06-12 09:06:01Z b_lindeijer $
  */
 
 #include "equipmenthandler.h"
@@ -26,9 +26,9 @@
 #include "messagein.h"
 #include "protocol.h"
 
-#include "../being.h"
 #include "../beingmanager.h"
 #include "../equipment.h"
+#include "../inventory.h"
 #include "../item.h"
 #include "../localplayer.h"
 #include "../log.h"
@@ -40,7 +40,6 @@ EquipmentHandler::EquipmentHandler()
     static const Uint16 _messages[] = {
         SMSG_PLAYER_EQUIPMENT,
         SMSG_PLAYER_EQUIP,
-        0x01d7,
         SMSG_PLAYER_UNEQUIP,
         SMSG_PLAYER_ARROW_EQUIP,
         SMSG_PLAYER_ATTACK_RANGE,
@@ -55,8 +54,8 @@ void EquipmentHandler::handleMessage(MessageIn *msg)
     Sint16 index, equipPoint, itemId;
     Sint8 type;
     int mask, position;
-    Being *being;
     Item *item;
+    Inventory *inventory = player_node->getInventory();
 
     switch (msg->getId())
     {
@@ -76,7 +75,7 @@ void EquipmentHandler::handleMessage(MessageIn *msg)
                 msg->readInt8();  // refine
                 msg->skip(8);     // card
 
-                player_node->addInvItem(index, itemId, 1, true);
+                inventory->setItem(index, itemId, 1, true);
 
                 if (equipPoint)
                 {
@@ -87,7 +86,7 @@ void EquipmentHandler::handleMessage(MessageIn *msg)
                         mask <<= 1;
                         position++;
                     }
-                    item = player_node->getInvItem(index);
+                    item = inventory->getItem(index);
                     player_node->mEquipment->setEquipment(position, item);
                 }
             }
@@ -123,27 +122,10 @@ void EquipmentHandler::handleMessage(MessageIn *msg)
                 item->setEquipped(false);
             }
 
-            item = player_node->getInvItem(index);
+            item = inventory->getItem(index);
             player_node->mEquipment->setEquipment(position, item);
             break;
 
-        case 0x01d7:
-            // Equipment related. At least confirmed to be required for weapon
-            // changes to appear on the local player.
-            being = beingManager->findBeing(msg->readInt32());
-            msg->readInt8();  // equip point
-            itemId = msg->readInt16();
-            msg->readInt16(); // item id 2
-            logger->log("0x01d7 (%s, itemId = %d)",
-                    (being == player_node) ? "player" : "somebody else",
-                    itemId);
-
-            if (!being)
-                break;
-
-            being->setSprite(Being::WEAPON_SPRITE, itemId);
-            break;
-
         case SMSG_PLAYER_UNEQUIP:
             index = msg->readInt16();
             equipPoint = msg->readInt16();
@@ -166,8 +148,7 @@ void EquipmentHandler::handleMessage(MessageIn *msg)
                 position++;
             }
 
-            item = player_node->getInvItem(index);
-
+            item = inventory->getItem(index);
             if (!item)
                 break;
 
@@ -201,18 +182,18 @@ void EquipmentHandler::handleMessage(MessageIn *msg)
             break;
 
         case SMSG_PLAYER_ARROW_EQUIP:
-            itemId = msg->readInt16();
+            index = msg->readInt16();
 
-            if (itemId <= 1)
+            if (index <= 1)
                 break;
 
-            item = player_node->getInvItem(itemId);
+            item = inventory->getItem(index);
             if (!item)
                 break;
 
             item->setEquipped(true);
             player_node->mEquipment->setArrows(item);
-            logger->log("Arrows equipped: %i", itemId);
+            logger->log("Arrows equipped: %i", index);
             break;
     }
 }
