@@ -18,13 +18,14 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: loginhandler.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: loginhandler.h 4425 2008-07-17 22:52:53Z b_lindeijer $
  */
 
 #ifndef _TMW_NET_LOGINHANDLER_H
 #define _TMW_NET_LOGINHANDLER_H
 
 #include "messagehandler.h"
+#include <string>
 
 struct LoginData;
 
@@ -37,8 +38,9 @@ class LoginHandler : public MessageHandler
 
         void setLoginData(LoginData *loginData) { mLoginData = loginData; };
 
-    protected:
+    private:
         LoginData *mLoginData;
+        std::string mUpdateHost;
 };
 
 #endif
