@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: tradehandler.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: tradehandler.h 4237 2008-05-14 18:57:32Z b_lindeijer $
  */
 
 #ifndef _TMW_NET_TRADEHANDLER_H
@@ -34,24 +34,6 @@ class TradeHandler : public MessageHandler
         TradeHandler();
 
         void handleMessage(MessageIn *msg);
-
-        /**
-         * Returns whether trade requests are accepted.
-         *
-         * @see setAcceptTradeRequests
-         */
-        bool acceptTradeRequests() const
-        { return mAcceptTradeRequests; }
-
-        /**
-         * Sets whether trade requests are accepted. When set to false, trade
-         * requests are automatically denied. When true, a popup will ask the
-         * player whether he wants to trade.
-         */
-        void setAcceptTradeRequests(bool acceptTradeRequests);
-
-    private:
-        bool mAcceptTradeRequests;
 };
 
 #endif
