@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: npc.cpp 4255 2008-05-21 21:44:27Z crush_tmw $
+ *  $Id: npc.cpp 4545 2008-08-28 20:29:06Z b_lindeijer $
  */
 
 #include "npc.h"
@@ -26,6 +26,7 @@
 #include "animatedsprite.h"
 #include "graphics.h"
 #include "particle.h"
+#include "text.h"
 
 #include "net/messageout.h"
 #include "net/protocol.h"
@@ -35,12 +36,15 @@
 
 NPC *current_npc = 0;
 
+static const int NAME_X_OFFSET = 15;
+static const int NAME_Y_OFFSET = 30;
+
 NPC::NPC(Uint32 id, Uint16 job, Map *map, Network *network):
     Being(id, job, map), mNetwork(network)
 {
     NPCInfo info = NPCDB::get(job);
 
-    //setup NPC sprites
+    // Setup NPC sprites
     int c = BASE_SPRITE;
     for (std::list<NPCsprite*>::const_iterator i = info.sprites.begin();
          i != info.sprites.end();
@@ -54,7 +58,7 @@ NPC::NPC(Uint32 id, Uint16 job, Map *map, Network *network):
         c++;
     }
 
-    //setup particle effects
+    // Setup particle effects
     for (std::list<std::string>::const_iterator i = info.particles.begin();
          i != info.particles.end();
          i++)
@@ -62,6 +66,20 @@ NPC::NPC(Uint32 id, Uint16 job, Map *map, Network *network):
         Particle *p = particleEngine->addEffect(*i, 0, 0);
         this->controlParticle(p);
     }
+    mName = 0;
+}
+
+NPC::~NPC()
+{
+    delete mName;
+}
+
+void NPC::setName(const std::string &name)
+{
+    delete mName;
+    mName = new Text(name, mPx + NAME_X_OFFSET, mPy + NAME_Y_OFFSET,
+                     gcn::Graphics::CENTER, speechFont,
+                     gcn::Color(200, 200, 255));
 }
 
 Being::Type
@@ -70,17 +88,6 @@ NPC::getType() const
     return Being::NPC;
 }
 
-void
-NPC::drawName(Graphics *graphics, Sint32 offsetX, Sint32 offsetY)
-{
-    int px = mPx + offsetX;
-    int py = mPy + offsetY;
-
-    graphics->setFont(speechFont);
-    graphics->setColor(gcn::Color(200, 200, 255));
-    graphics->drawText(mName, px + 15, py + 30, gcn::Graphics::CENTER);
-}
-
 void
 NPC::talk()
 {
@@ -129,3 +136,11 @@ NPC::sell()
     outMsg.writeInt32(mId);
     outMsg.writeInt8(1);
 }
+
+void NPC::updateCoords()
+{
+    if (mName)
+    {
+        mName->adviseXY(mPx + NAME_X_OFFSET, mPy + NAME_Y_OFFSET);
+    }
+}
