@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: openglgraphics.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: openglgraphics.cpp 4130 2008-04-18 20:39:29Z the_enemy $
  */
 
 #include "main.h"
@@ -76,8 +76,8 @@ bool OpenGLGraphics::setVideoMode(int w, int h, int bpp, bool fs, bool hwaccel)
     }
 
 #ifdef __APPLE__
-    long VBL = 1;
-    CGLSetParameter(CGLGetCurrentContext(), kCGLCPSwapInterval, &VBL);
+//    long VBL = 1;
+//    CGLSetParameter(CGLGetCurrentContext(), kCGLCPSwapInterval, &VBL);
 #endif
 
     // Setup OpenGL
