@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: buddylist.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: buddylist.cpp 4332 2008-06-05 07:33:12Z b_lindeijer $
  */
 
 #include <algorithm>
@@ -33,8 +33,12 @@
 
 BuddyList::BuddyList()
 {
+    // TODO: A buddy list would have to use the Configuration class to store
+    //       the buddies. Also, there is now a player relationship manager
+    //       which probably makes this buddy list kind of obsolete.
+
     // Find saved buddy list file
-    mFilename = config.getValue("homeDir", "") + "/buddy.txt";
+    //mFilename = homeDir + "/buddy.txt";
 
     // Load buddy from file
     loadFile();
