@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: imageset.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: imageset.h 4375 2008-07-01 17:41:30Z b_lindeijer $
  */
 
 #ifndef _TMW_IMAGESET_H
@@ -47,14 +47,20 @@ class ImageSet : public Resource
          */
         ~ImageSet();
 
-        int getWidth() { return mWidth; };
+        /**
+         * Returns the width of the images in the image set.
+         */
+        int getWidth() const { return mWidth; };
 
-        int getHeight() { return mHeight; };
+        /**
+         * Returns the height of the images in the image set.
+         */
+        int getHeight() const { return mHeight; };
 
         typedef std::vector<Image*>::size_type size_type;
-        Image* get(size_type i);
+        Image* get(size_type i) const;
 
-        size_type size() { return mImages.size(); }
+        size_type size() const { return mImages.size(); }
 
     private:
         std::vector<Image*> mImages;
