@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: itemdb.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: itemdb.cpp 4347 2008-06-12 09:06:01Z b_lindeijer $
  */
 
 #include <algorithm>
@@ -55,30 +55,16 @@ void ItemDB::load()
 
     mUnknown = new ItemInfo();
     mUnknown->setName("Unknown item");
-    mUnknown->setImage("");
+    mUnknown->setImageName("");
     mUnknown->setSprite("error.xml", 0);
     mUnknown->setSprite("error.xml", 1);
 
-    ResourceManager *resman = ResourceManager::getInstance();
-    int size;
-    char *data = (char*) resman->loadFile("items.xml", size);
+    XML::Document doc("items.xml");
+    xmlNodePtr rootNode = doc.rootNode();
 
-    if (!data) {
-        logger->error("ItemDB: Could not find items.xml!");
-    }
-
-    xmlDocPtr doc = xmlParseMemory(data, size);
-    free(data);
-
-    if (!doc)
-    {
-        logger->error("ItemDB: Error while parsing item database (items.xml)!");
-    }
-
-    xmlNodePtr rootNode = xmlDocGetRootElement(doc);
     if (!rootNode || !xmlStrEqual(rootNode->name, BAD_CAST "items"))
     {
-        logger->error("ItemDB: items.xml is not a valid database file!");
+        logger->error("ItemDB: Error while loading items.xml!");
     }
 
     for_each_xml_child_node(node, rootNode)
@@ -111,7 +97,7 @@ void ItemDB::load()
         if (id)
         {
             ItemInfo *itemInfo = new ItemInfo();
-            itemInfo->setImage(image);
+            itemInfo->setImageName(image);
             itemInfo->setName((name == "") ? "Unnamed" : name);
             itemInfo->setDescription(description);
             itemInfo->setEffect(effect);
@@ -150,8 +136,6 @@ void ItemDB::load()
 #undef CHECK_PARAM
     }
 
-    xmlFreeDoc(doc);
-
     mLoaded = true;
 }
 
