@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: iteminfo.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: iteminfo.h 4347 2008-06-12 09:06:01Z b_lindeijer $
  */
 
 #ifndef _TMW_ITEMINFO_H_
@@ -30,8 +30,6 @@
 
 #include "spritedef.h"
 
-class Image;
-
 enum EquipmentSoundEvent
 {
     EQUIP_EVENT_STRIKE,
@@ -49,7 +47,6 @@ class ItemInfo
          * Constructor.
          */
         ItemInfo():
-            mImage(NULL),
             mType(0),
             mWeight(0),
             mView(0),
@@ -57,21 +54,17 @@ class ItemInfo
         {
         }
 
-        /**
-         * Destructor.
-         */
-        ~ItemInfo();
-
         void setName(const std::string &name)
         { mName = name; }
 
         const std::string& getName() const
         { return mName; }
 
-        void setImage(const std::string &image);
+        void setImageName(const std::string &imageName)
+        { mImageName = imageName; }
 
-        Image* getImage() const
-        { return mImage; }
+        const std::string& getImageName() const
+        { return mImageName; }
 
         void setDescription(const std::string &description)
         { mDescription = description; }
@@ -116,13 +109,6 @@ class ItemInfo
 
     protected:
         std::string mImageName;        /**< The filename of the icon image. */
-
-        /* TODO (BL): I do not think the item info should keep a reference to
-         * the item icon. It would probably be better if this was kept in the
-         * Item class, so that the images can be lazily instantiated and also
-         * unloaded when no longer used.
-         */
-        Image *mImage;                 /**< The loaded icon image. */
         std::string mName;
         std::string mDescription;      /**< Short description. */
         std::string mEffect;           /**< Description of effects. */
