@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: resourcemanager.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: resourcemanager.cpp 4347 2008-06-12 09:06:01Z b_lindeijer $
  */
 
 #include <cassert>
@@ -98,11 +98,15 @@ ResourceManager::~ResourceManager()
 void
 ResourceManager::cleanUp(Resource *res)
 {
-    logger->log("ResourceManager::~ResourceManager() cleaning up %d "
+    if (res->mRefCount > 0)
+    {
+        logger->log("ResourceManager::~ResourceManager() cleaning up %d "
                 "reference%s to %s",
                 res->mRefCount,
                 (res->mRefCount == 1) ? "" : "s",
                 res->mIdPath.c_str());
+    }
+
     delete res;
 }
 
@@ -446,9 +450,8 @@ ResourceManager::loadTextFile(const std::string &fileName)
     std::istringstream iss(std::string(fileContents, contentsLength));
     std::string line;
 
-    while (getline(iss, line, '\n')) {
+    while (getline(iss, line))
         lines.push_back(line);
-    }
 
     free(fileContents);
     return lines;
