@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: spritedef.h 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: spritedef.h 4375 2008-07-01 17:41:30Z b_lindeijer $
  */
 
 #ifndef _TMW_SPRITEDEF_H
@@ -81,17 +81,22 @@ class SpriteDef : public Resource
         Action *getAction(SpriteAction action) const;
 
     private:
-
         /**
          * Constructor.
          */
-        SpriteDef(): mAction(NULL), mDirection(DIRECTION_DOWN), mLastTime(0) {}
+        SpriteDef() {}
 
         /**
          * Destructor.
          */
         ~SpriteDef();
 
+        /**
+         * Loads a sprite element.
+         */
+        void loadSprite(xmlNodePtr spriteNode, int variant,
+                        const std::string &palettes = "");
+
         /**
          * Loads an imageset element.
          */
@@ -149,9 +154,6 @@ class SpriteDef : public Resource
 
         ImageSets mImageSets;
         Actions mActions;
-        Action *mAction;
-        SpriteDirection mDirection;
-        int mLastTime;
 };
 
 #endif
