@@ -18,7 +18,7 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: textparticle.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: textparticle.cpp 4360 2008-06-23 14:44:20Z crush_tmw $
  */
 
 #include "textparticle.h"
@@ -45,7 +45,7 @@ void TextParticle::draw(Graphics *graphics, int offsetX, int offsetY) const
     int screenX = (int) mPos.x + offsetX;
     int screenY = (int) mPos.y - (int) mPos.z + offsetY;
 
-    int alpha = 255;
+    float alpha = mAlpha * 255.0f;
 
     if (mLifetimeLeft > -1 && mLifetimeLeft < mFadeOut)
     {
@@ -60,6 +60,6 @@ void TextParticle::draw(Graphics *graphics, int offsetX, int offsetY) const
     }
 
     graphics->setFont(mTextFont);
-    graphics->setColor(gcn::Color(mColorR, mColorG, mColorB, alpha));
+    graphics->setColor(gcn::Color(mColorR, mColorG, mColorB, (int)alpha));
     graphics->drawText(mText, screenX, screenY, gcn::Graphics::CENTER);
 }
