@@ -18,13 +18,49 @@
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: xml.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
+ *  $Id: xml.cpp 4255 2008-05-21 21:44:27Z crush_tmw $
  */
 
 #include "xml.h"
+#include "../log.h"
+#include "../resources/resourcemanager.h"
 
 namespace XML
 {
+    Document::Document(const std::string &filename):
+        mDoc(NULL)
+    {
+        int size;
+        ResourceManager *resman = ResourceManager::getInstance();
+        char *data = (char*) resman->loadFile(filename.c_str(), size);
+
+        if (data) {
+            mDoc = xmlParseMemory(data, size);
+            free(data);
+
+            if (!mDoc)
+                logger->log("Error parsing XML file %s", filename.c_str());
+        } else {
+            logger->log("Error loading %s", filename.c_str());
+        }
+    }
+
+    Document::Document(const char *data, int size)
+    {
+        mDoc = xmlParseMemory(data, size);
+    }
+
+    Document::~Document()
+    {
+        if (mDoc)
+            xmlFreeDoc(mDoc);
+    }
+
+    xmlNodePtr Document::rootNode()
+    {
+        return mDoc ? xmlDocGetRootElement(mDoc) : 0;
+    }
+
     int
     getProperty(xmlNodePtr node, const char* name, int def)
     {
